/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.interceptor.description;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 * 
 */
public class ExtensibleElementInterceptorConfiguration {

    /**
     * The order of the interceptors. On an accept message, the interceptors
     * MUST be launched with this defined order;
     */
    protected Map<String, InterceptorConfiguration> inputInterceptors;

    /**
     * The order of the interceptors. On an accept message response, the
     * interceptors MUST be launched with this defined order;
     */
    protected Map<String, InterceptorConfiguration> inputResponseInterceptors;

    /**
     * The order of the interceptors. On a send message, the interceptors MUST
     * be launched with this defined order;
     */
    protected Map<String, InterceptorConfiguration> outputInterceptors;

    /**
     * The order of the interceptors. On an send message response, the
     * interceptors MUST be launched with this defined order;
     */
    protected Map<String, InterceptorConfiguration> outputResponseInterceptors;

    /**
     * Creates a new instance of
     * {@link ExtensibleElementInterceptorConfiguration}
     * 
     */
    public ExtensibleElementInterceptorConfiguration() {
        this.inputInterceptors = new LinkedHashMap<String, InterceptorConfiguration>();
        this.inputResponseInterceptors = new LinkedHashMap<String, InterceptorConfiguration>();
        this.outputInterceptors = new LinkedHashMap<String, InterceptorConfiguration>();
        this.outputResponseInterceptors = new LinkedHashMap<String, InterceptorConfiguration>();
    }

    /**
     * @return the inputInterceptors
     */
    public Map<String, InterceptorConfiguration> getInputInterceptors() {
        return this.inputInterceptors;
    }

    /**
     * @param inputInterceptors
     *            the inputInterceptors to set
     */
    public void setInputInterceptors(Map<String, InterceptorConfiguration> inputInterceptors) {
        this.inputInterceptors = inputInterceptors;
    }

    /**
     * @return the outputInterceptors
     */
    public Map<String, InterceptorConfiguration> getOutputInterceptors() {
        return this.outputInterceptors;
    }

    /**
     * @param outputInterceptors
     *            the outputInterceptors to set
     */
    public void setOutputInterceptors(Map<String, InterceptorConfiguration> outputInterceptors) {
        this.outputInterceptors = outputInterceptors;
    }

    /**
     * @return the inputResponseInterceptors
     */
    public Map<String, InterceptorConfiguration> getInputResponseInterceptors() {
        return this.inputResponseInterceptors;
    }

    /**
     * @param inputResponseInterceptors the inputResponseInterceptors to set
     */
    public void setInputResponseInterceptors(
            Map<String, InterceptorConfiguration> inputResponseInterceptors) {
        this.inputResponseInterceptors = inputResponseInterceptors;
    }

    /**
     * @return the outputResponseInterceptors
     */
    public Map<String, InterceptorConfiguration> getOutputResponseInterceptors() {
        return this.outputResponseInterceptors;
    }

    /**
     * @param outputResponseInterceptors the outputResponseInterceptors to set
     */
    public void setOutputResponseInterceptors(
            Map<String, InterceptorConfiguration> outputResponseInterceptors) {
        this.outputResponseInterceptors = outputResponseInterceptors;
    }

}
