/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.interceptor.impl;

import java.util.Map;
import java.util.logging.Level;

import org.objectweb.petals.component.framework.interceptor.Interceptor;
import org.objectweb.petals.component.framework.util.Exchange;
import org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement;

/**
 * A simple interceptor which prints the message exchange properties.
 * 
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 * 
 */
public class EchoInterceptor extends Interceptor {

    /**
     * Creates a new instance of {@link EchoInterceptor}
     * 
     */
    public EchoInterceptor() {
        super();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#onMessageAccept(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement)
     */
    @Override
    public void handleMessageAccept(Exchange mex, ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> parameters) {
        logger.log(Level.INFO, "ACCEPT : " + mex.getExchangeId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#onMessageSent(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement)
     */
    @Override
    public void handleMessageSent(Exchange messageExchange,
            ServiceUnitExtensibleElement consumeProvide, Map<String, String> parameters) {
        logger.log(Level.INFO, "SENT : " + messageExchange.getExchangeId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageAcceptResponse(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageAcceptResponse(Exchange exchange,
            ServiceUnitExtensibleElement consumeProvide, Map<String, String> parameters) {
        logger.log(Level.INFO, "ACCEPT RESPONSE : " + exchange.getExchangeId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageSentResponse(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageSentResponse(Exchange exchange,
            ServiceUnitExtensibleElement consumeProvide, Map<String, String> parameters) {
        logger.log(Level.INFO, "SEND RESPONSE : " + exchange.getExchangeId());
    }
}
