/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.interceptor.impl;

import java.util.Map;

import org.objectweb.petals.component.framework.interceptor.Interceptor;
import org.objectweb.petals.component.framework.util.Exchange;
import org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement;

/**
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 * 
 */
public class MessageInfoPrintInterceptor extends Interceptor {

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#onMessageAccept(javax.jbi.messaging.MessageExchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageAccept(Exchange mex, ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> additionalParameters) {

        this.printInfo(mex, additionalParameters, "ACCEPT");
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#onMessageSent(javax.jbi.messaging.MessageExchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageSent(Exchange mex, ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> additionalParameters) {
        this.printInfo(mex, additionalParameters, "SEND");
    }

    /**
     * 
     * @param mex
     * @param additionalParameters
     * @param mode
     */
    private void printInfo(Exchange mex, Map<String, String> additionalParameters, String mode) {
        System.out.println("###################################");
        System.out.println(mode);
        System.out.println(mex.getExchangeId());
        System.out.println(mex.getStatus().toString());

        System.out.println("Component level parameters : " + componentParameters);

        System.out.println("Service unit level parameters : " + additionalParameters);

        System.out.println("####################################");

    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageAcceptResponse(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageAcceptResponse(Exchange mex,
            ServiceUnitExtensibleElement consumeProvide, Map<String, String> additionalParameters) {
        this.printInfo(mex, additionalParameters, "ACCEPT RESPONSE");

    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageSentResponse(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageSentResponse(Exchange mex,
            ServiceUnitExtensibleElement consumeProvide, Map<String, String> additionalParameters) {
        this.printInfo(mex, additionalParameters, "SEND RESPONSE");

    }

}
