/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * AbstractExternalListener.java - Initial Developper : ofabre
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.listener;

import javax.jbi.component.ComponentContext;
import javax.jbi.messaging.MessagingException;
import javax.jbi.servicedesc.ServiceEndpoint;

import org.objectweb.petals.component.framework.MEPConstants;
import org.objectweb.petals.component.framework.PEtALSCDKException;
import org.objectweb.petals.component.framework.util.Exchange;
import org.objectweb.petals.component.framework.util.Extensions;

/**
 *
 * @author alouis, ofabre - EBM Websourcing
 *
 */
public abstract class AbstractExternalListener extends AbstractListener {

	/**
     * The JBI Component context.
     */
    private ComponentContext componentContext;

    /**
     * Initialize the listener.
     *
     * @param component
     */
    public final void initAbstractExternalListener(ComponentContext cc) {
        this.componentContext = cc;
    }


    /**
     * Starts the listener. This method is called when the SU that causes this
     * listener instantiation is started.
     *
     * @throws PEtALSCDKException
     *             if an error occurs during external listener starting process
     */
    protected abstract void start() throws PEtALSCDKException;

    /**
     * Stops the listener. This method is called when the SU that causes this
     * listener instantiation is stopped.
     *
     * @throws PEtALSCDKException
     *             if an error occurs during external listener stopping process
     */
    protected abstract void stop() throws PEtALSCDKException;



    /**
     * Create a message exchange with all the information
     * set in the CONSUME block of the related serviceunit:
     * <br>- service information (itf, srv, ep)
     * <br>- MEP
     * <br>- operation
     * <br>- PEtALS exchange' meta-data (org.objectweb.petals.xxx)
     * @return a message exchange set with Consumes attributes
     * @throws MessagingException
     *             if the message exchange can't be created or if no pattern specified in extensions
     */
    public Exchange createConsumeExchange()
            throws MessagingException {
        Extensions extensions = getExtensions();
        MEPConstants mep = retrievePattern(extensions);
        return createConsumeExchange(mep);
    }

    /**
     * Create a message exchange with all the information
     * set in the CONSUME block of the related serviceunit:
     * <br>- service information (itf, srv, ep)
     * <br>- operation
     * <br>- PEtALS exchange' meta-data (org.objectweb.petals.xxx)
     * @param mep
     *            a specific MEP pattern
     * @return a message exchange matching the given pattern
     * @throws MessagingException
     *             if the message exchange can't be created or if the specified
     *             pattern isn't valid
     */
    public Exchange createConsumeExchange(MEPConstants mep)
            throws MessagingException {
        Exchange exchange = createExchange(mep);
        setOperationFromExtensions(exchange);
        setMessageExchangePropertiesFromExtensions(exchange);
        setExchangeDestination(exchange);
        return exchange;
    }


    /**
     * Fill the exchange with the service information (itf,src, and ep) from the consume extension
     * @param exchange
     */
    private void setExchangeDestination(final Exchange exchange) {
        // Retrieve possible target endpoint
        ServiceEndpoint ep = null;
        if (consumes.getEndpointName() != null
                && consumes.getServiceName() != null) {
            ep = this.componentContext.getEndpoint(consumes.getServiceName(),
                    consumes.getEndpointName());
        }
        // set exchange information
        exchange.setInterfaceName(consumes.getInterfaceName());
        exchange.setService(consumes.getServiceName());
        exchange.setEndpoint(ep);
    }

    /*
     * (non-Javadoc)
     * @see org.objectweb.petals.component.framework.listener.AbstractListener#getExtensions()
     */
    protected final Extensions getExtensions() {
        Extensions extensions = null;
        if (consumes != null) {
            extensions = new Extensions(consumes.getExtensions());
        }
        return extensions;
    }
}
